==> image-go-nord-0.0.4.tar.gz: image-go-nord-0.0.4/README.md <==
# ImageGoNord - RGB image to Nordtheme palette
A tool that can convert your rgb images to nordtheme palette.

This repository is a CLI utility, written in python, that can convert any sort of image into a [nordtheme](https://github.com/arcticicestudio/nord) palette image.
<br>We are planning to make also an API so it can be more user friendly.

<!--
@TODO
- Describe very briefly but clearly what the project does.
- State if it is out-of-the-box user-friendly, so it’s clear to the user.
- List its most useful/innovative/noteworthy features.
- State its goals/what problem(s) it solves.
- Note and briefly describe any key concepts (technical, philosophical, or both) important to the user’s understanding.
- Link to any supplementary blog posts or project main pages.
- Note its development status.
- Include badges.
- If possible, include screenshots and demo videos.
-->

### Inspiration

We are in love with Nordtheme, that is why we created this repository.

[![Nord Color Palette Overview](https://raw.githubusercontent.com/arcticicestudio/nord-docs/develop/assets/images/nord/repository-color-palettes.svg?sanitize=true)](https://www.nordtheme.com/docs/colors-and-palettes)

Our goal is to make a shortcut to convert anything into this theme, by starting from the images.
<br>An example could be an awesome wallpaper converted into the Nordtheme palette.

We checked the commnunity and we did not find anything similar or any project that can accomplish this task. So, here we are.

### Core Technical Concepts

We are using the PIL because it is the most simple library and it is very useful when you need to manipolate some images.

Our goal is also to make this project open source and maintainable by the community. We would love to.

*We believe in the open source community.*

### Getting Started
Include any essential instructions for:
- Getting it
- Installing It
- Configuring It
- Running it

### Testing
- Tests **TODO**

### Contributing
- Follow the contributor guidelines
- Follow the code style / requirements
- Format for commit messages

### TODO
- Portable environemnt
- Testing
- Improvements on image quality and supporting any image format
- Make contributing guidelines
- API / UI

# Authors

[TheJoin95](https://github.com/TheJoin95) & [Wabri](https://github.com/Wabri)

**NOTE**: we are not (yet) affiliated with the Nordtheme or [Arcticicestudio](https://github.com/arcticicestudio).

# Credits

[Nordtheme](https://www.nordtheme.com/)

### License

[MIT license](https://github.com/Schrodinger-Hat/ImageGoNord/blob/master/LICENSE)

==> image-go-nord-0.0.5.tar.gz: image-go-nord-0.0.5/README.md <==
# ImageGoNord - RGB image to Nordtheme palette

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/image-go-nord)
![PyPI](https://img.shields.io/pypi/v/image-go-nord)
[![license](https://img.shields.io/badge/license-MIT-green)](https://github.com/Schrodinger-Hat/ImageGoNord-pip/blob/master/LICENSE)
[![Join the community on Spectrum](https://withspectrum.github.io/badge/badge.svg)](https://spectrum.chat/image-go-nord)

A tool that can convert your rgb images to nordtheme palette.

This repository is a CLI utility, written in python, that can convert any sort of image into a [nordtheme](https://github.com/arcticicestudio/nord) palette image.
<br>We are planning to make also an API so it can be more user friendly.

<!--
@TODO
- Describe very briefly but clearly what the project does.
- State if it is out-of-the-box user-friendly, so it’s clear to the user.
- List its most useful/innovative/noteworthy features.
- State its goals/what problem(s) it solves.
- Note and briefly describe any key concepts (technical, philosophical, or both) important to the user’s understanding.
- Link to any supplementary blog posts or project main pages.
- Note its development status.
- Include badges.
- If possible, include screenshots and demo videos.
-->

### Inspiration

We are in love with Nordtheme, that is why we created this repository.

[![Nord Color Palette Overview](https://raw.githubusercontent.com/arcticicestudio/nord-docs/develop/assets/images/nord/repository-color-palettes.svg?sanitize=true)](https://www.nordtheme.com/docs/colors-and-palettes)

Our goal is to make a shortcut to convert anything into this theme, by starting from the images.
<br>An example could be an awesome wallpaper converted into the Nordtheme palette.

We checked the commnunity and we did not find anything similar or any project that can accomplish this task. So, here we are.

### Core Technical Concepts

We are using the PIL because it is the most simple library and it is very useful when you need to manipolate some images.

Our goal is also to make this project open source and maintainable by the community. We would love to.

*We believe in the open source community.*

### Getting Started
Include any essential instructions for:
- Getting it
- Installing It
- Configuring It
- Running it

### Testing
- Tests **TODO**

### Contributing
- Follow the contributor guidelines
- Follow the code style / requirements
- Format for commit messages

### TODO
- Portable environemnt
- Testing
- Improvements on image quality and supporting any image format
- Make contributing guidelines
- API / UI

# Authors

[TheJoin95](https://github.com/TheJoin95) & [Wabri](https://github.com/Wabri)

**NOTE**: we are not (yet) affiliated with the Nordtheme or [Arcticicestudio](https://github.com/arcticicestudio).

# Credits

[Nordtheme](https://www.nordtheme.com/)

### License

[MIT license](https://github.com/Schrodinger-Hat/ImageGoNord/blob/master/LICENSE)
